@@ -5,9 +5,6 @@ import glob
 import astropy_stark.cream_lcplot as cream_plot
 import astropy_stark.cream_plotlibrary as cpl
 import matplotlib.pylab as plt
-import multiprocessing as mp
-import time
-
 
 class pycecream:
     '''
@@ -45,9 +42,8 @@ class pycecream:
         print('pycecream path... ' + self.module_path)
 
         #convention parameters
-        self.project_folder = 'pycecream'
+        self.output_directory = 'pycecream'
         self.append_date_to_output_directory = False
-        self.save_ALL_parameters = True
 
         #global non-fitted parameters
         self.redshift = 0.0
@@ -106,9 +102,9 @@ class pycecream:
         :return:
         '''
         #make a directory into which to store the cream results
-        dir_pycecream = self.project_folder
+        dir_pycecream = self.output_directory
         if self.append_date_to_output_directory is True:
-            dir_pycecream = self.project_folder+'_'+str(pd.datetime.today().strftime("%d_%m_%Y"))+'_'
+            dir_pycecream = self.output_directory+'_'+str(pd.datetime.today().strftime("%d_%m_%Y"))+'_'
             child_dirs = next(os.walk('.'))[1]
             number_of_pyceream_dirs = len( [c for c in child_dirs if dir_pycecream in c] )
             dir_pycecream = dir_pycecream+str(number_of_pyceream_dirs)
@@ -142,7 +138,8 @@ class pycecream:
                tophat_width = None,
                tophat_width_step = None,
                tophat_width_prior=[0.0, -0.1],
-               background_polynomials = None):
+
+    ):
         '''
         This is the go to command to add a new light curve into the
         simulation.
@@ -158,13 +155,8 @@ class pycecream:
         :param vertical_scaling_start: as above but for vertical scaling parameter.
         :param background_offset_prior: [mean,sd] of gaussian prior. Leave as None to ignore priors
         :param vertical_scaling_prior: as above but for the vertical scaling parameter
-        :param background_polynomials: add variable background list of starting coefficients for each level of polynomial
-        (advise [0.1,0.1] to add a quadratic polynomial )
         :return:
         '''
-        #assertion errors
-        assert(type(share_previous_lag) == bool)
-
         #set up the directory structure if first call
         if self.count_lightcurves == 0:
             self.setup_directory_structure()
@@ -237,8 +229,7 @@ class pycecream:
                                   background_offset_start,
                                   vertical_scaling_start,
                                   background_offset_prior,
-                                  vertical_scaling_prior,
-                                  background_polynomials
+                                  vertical_scaling_prior
                                   ],
                      index=['name', 'type', 'wavelength', 'noise model',
                             'extra variance prior','multiplicative errorbar prior',
@@ -252,8 +243,7 @@ class pycecream:
                             'tophat width prior cent',
                             'tophat width prior width',
                             'background offset start','vertical scaling start',
-                            'background offset prior','vertical scaling prior',
-                            'background_polynomials']).T
+                            'background offset prior','vertical scaling prior']).T
 
         self.lightcurve_input_params = pd.DataFrame(pd.concat([self.lightcurve_input_params,df]))
         self.lightcurve_input_params['wavelength']= \
@@ -283,15 +273,12 @@ class pycecream:
         # lines for each of the input parameters in creaminpar.par (dont change)
         idcos = 37
         idmdot = 31
-        idmass = 32
-        idefficiency = 25
         idslope = 70
         idsig = 22
         idnits = 10
         idplot = 4
         idlaglim = 13
         idhifreq = 9
-        idallparsave = 2
 
         #modify and write the creaminpar.par file as needed
         with open(self.dir_pycecream+'/creaminpar.par') as f:
@@ -301,10 +288,8 @@ class pycecream:
             content[0] = './'+np.str(self.dir_sim)
             f.close()
         content[idcos] = np.str(self.p_inclination)
-        content[idefficiency] = np.str(self.bh_efficieny)
         content[idcos+1] = np.str(self.p_inclination_step)
         content[idmdot] = np.str(self.p_accretion_rate)
-        content[idmass] = np.str(self.bh_mass)
         content[idmdot+3] = np.str(self.p_accretion_rate_step)
         content[idslope] = np.str(self.p_viscous_slope)
         content[idslope+2] = np.str(self.p_viscous_slope_step)
@@ -331,10 +316,6 @@ class pycecream:
         content[idsig - 1] = a
         content[idsig - 2] = turn_on_multiplicative_noise
 
-        # decide whether to record all Fourier parameters (possible bad for storage space)
-        if self.save_ALL_parameters == True:
-            content[idallparsave] = 'F T'
-
         #write updated creaminpar.par file
         f = open(self.dir_pycecream+'/creaminpar.par', 'w')
         for fn in content:
@@ -342,7 +323,6 @@ class pycecream:
         f.close()
 
 
-
     def set_creamnames(self):
         '''
         set the creamnames.dat file summarising the file names and wavelengths
@@ -431,37 +411,6 @@ class pycecream:
         f.close()
 
 
-    def set_background_polynomials(self):
-        '''
-        allows a smooth background function to be fitted to each light curve alongside lamppost model
-        If background_polynomial parameters not configured then this function does nothing
-        :return:
-        '''
-        all_polys = self.lightcurve_input_params['background_polynomials']
-        NPpoly = 0
-        Nwavs = len(self.lightcurve_input_params)
-        # need a 2D array of polynomial coefficients but may user specifies these as a list
-        # of variable lengths take maximum length and set other coeffs to 0
-        for p in all_polys:
-            if p is not None:
-                NPpoly = max(NPpoly,len(p))
-        poly_coefs = np.zeros((Nwavs,NPpoly))
-        for i in range(Nwavs):
-            if all_polys.iloc[i] is not None:
-                Npoly_now = len(all_polys.iloc[i])
-                poly_coefs[i,:Npoly_now] = all_polys.iloc[i]
-
-        #populate the cream file creaminpar_bg.par
-        if NPpoly > 0:
-            f = open(self.dir_pycecream + '/' + self.dir_sim + '/creaminpar_bg.par', 'w')
-            f.write(str(NPpoly)+'\n')
-            f.write(' '.join(['0.0']*NPpoly)+'\n')
-            for i in range(Nwavs):
-                x = list(poly_coefs[i,:])
-                f.write(' '.join([str(xx) for xx in x])+'\n')
-                f.write(' '.join(['0.0']*NPpoly)+'\n') #no priors allowed
-
-
 
 
     def set_var(self):
@@ -483,7 +432,7 @@ class pycecream:
 
 
 
-    def run(self,ncores = 1):
+    def run(self):
         '''
         run the cream code. Make sure input above is correct first
         :return:
@@ -494,7 +443,6 @@ class pycecream:
         self.set_creamnames()
         self.set_tophat()
         self.set_var()
-        self.set_background_polynomials()
         self.set_start_offsert_vertical()
         self.set_priors()
 
@@ -503,23 +451,10 @@ class pycecream:
         self.lightcurve_input_params.to_csv('./simulation_files/input_lightcurve_settings.csv')
 
         #compile and run
-        # with mp.Pool(ncores) as p:
-        #    p.map(_run_cmd,[('./creamrun.exe',self.dir_pwd)]*ncores)
-
         os.system(self.fortran_compile_command)
-        jobs = []
-        for i in range(ncores):
-            p = mp.Process(target = _run_cmd, args=('./creamrun.exe',))
-            jobs.append(p)
-            p.start()
-            time.sleep(0.4)
-        #wait for jobs to finish before continuing
-        for j in jobs:
-            j.join()
+        os.system('./creamrun.exe')
         os.chdir(self.dir_pwd)
 
-    #def run_parallel(self,ncores=1):
-
 
     def get_simulation_dir(self,location=None):
         '''
@@ -543,105 +478,43 @@ class pycecream:
         '''
         #locate the simulation results
         simulation_dir = self.get_simulation_dir(location=location)
-        lcnames = list(self.lightcurve_input_params['name'])
-        n_lightcurves = len(lcnames)
-        results_dir_list = glob.glob(simulation_dir + '/simulation_files/output_2*')
+        lcnames = self.lightcurve_input_params['name']
+        results_dir = glob.glob(simulation_dir + '/simulation_files/output_2*')[0]
+        '''
+        Begin loading the simulation results from the various stored locations
+        '''
 
-        self.output_parameters = pd.DataFrame()
-        idx_chain = 0
-        for results_dir in results_dir_list:
-            '''
-            Begin loading the simulation results from the various stored locations
-            '''
+        #load the disk parameters
+        dat_output = np.loadtxt(results_dir + '/outputpars.dat')
+        p_output_names = ['Mdot','cos i','Tr_alpha']
+        p_output = dat_output[:,[2,3,4]]
 
-            #load the disk parameters
-            dat_output = np.loadtxt(results_dir + '/outputpars.dat')
-            p_output_names = ['Mdot','cos i','Tr_alpha']
-            p_output = dat_output[:,[2,3,4]]
+        #load the stretch, offset and multiplicative error bar rescaling parameters
+        dat_output = np.loadtxt(results_dir + '/outputpars2.dat')
+        p_output_names = p_output_names + ['stretch '+l for l in lcnames] + \
+                         ['offset '+l for l in lcnames] + \
+                         ['noise m '+l for l in lcnames]
+        p_output = np.hstack((p_output,dat_output[:,:3*self.count_lightcurves]))
 
-            #load the stretch, offset and multiplicative error bar rescaling parameters
-            dat_output = np.loadtxt(results_dir + '/outputpars2.dat')
-            p_output_names = p_output_names + ['stretch '+l for l in lcnames] + \
-                             ['offset '+l for l in lcnames] + \
-                             ['noise m '+l for l in lcnames]
-            p_output = np.hstack((p_output,dat_output[:,:3*self.count_lightcurves]))
+        #load the extra variance noise parameters
+        dat_output = np.loadtxt(results_dir + '/outputpars_varexpand.dat')
+        p_output_names = p_output_names + \
+                         ['noise var '+l for l in lcnames]
+        p_output = np.hstack((p_output,dat_output))
 
-            #load the extra variance noise parameters
-            dat_output = np.loadtxt(results_dir + '/outputpars_varexpand.dat')
-            p_output_names = p_output_names + \
-                             ['noise var '+l for l in lcnames]
-            p_output = np.hstack((p_output,dat_output))
+        #load the top hat centroid parameters
+        dat_output = np.loadtxt(results_dir + '/outputpars_th.dat')
+        p_output_names = p_output_names + \
+                         ['top hat centroid '+l for l in lcnames] + \
+                         ['top hat width '+l for l in lcnames]
+        p_output = np.hstack((p_output,dat_output[:,:2*self.count_lightcurves]))
 
-            #load the top hat centroid parameters
-            dat_output = np.loadtxt(results_dir + '/outputpars_th.dat')
-            p_output_names = p_output_names + \
-                             ['top hat centroid '+l for l in lcnames] + \
-                             ['top hat width '+l for l in lcnames]
-            p_output = np.hstack((p_output,dat_output[:,:2*self.count_lightcurves]))
+        #save all results for each MCMC iteration to a pandas data frame
+        self.output_parameters = pd.DataFrame(data = p_output,columns = p_output_names)
 
-
-            #load the polynomial background parameters if present
-            file_polynomial_background = results_dir + '/outputpars_bgvary.dat'
-            polynomial_background_exists = os.path.isfile(file_polynomial_background)
-            if polynomial_background_exists is True:
-                dat_pbg = np.loadtxt(file_polynomial_background,ndmin=2)
-                nrows,ncols = np.shape(dat_pbg)
-                n_pbg = int(ncols/2)
-                p_pbg = dat_pbg[:,:n_pbg]
-                norder = int(n_pbg/n_lightcurves)
-                p_pbg_names = []
-                for i in range(n_lightcurves):
-                    p_pbg_names += [lcnames[i]+' ng polynomial order '+str(i2+1) for i2 in range(norder)]
-                p_output_names = p_output_names + p_pbg_names
-                p_output = np.hstack((p_output,p_pbg))
-
-            #save all results for each MCMC iteration to a pandas data frame
-            print(np.shape(p_output))
-            print(len(p_output_names))
-            p_output = pd.DataFrame(data = p_output,columns = p_output_names)
-            p_output['chain number'] = idx_chain
-            self.output_parameters = self.output_parameters.append(p_output)
-            idx_chain += 1
         return(self.output_parameters)
 
 
-    def get_MCMC_fourier_chains(self,location = None):
-        '''
-        retrieve the fourier parameters
-        :param location:
-        :return:
-        '''
-        #locate the simulation results
-        simulation_dir = self.get_simulation_dir(location=location)
-
-        results_dir_list = glob.glob(simulation_dir + '/simulation_files/output_2*')
-
-        self.output_parameters = pd.DataFrame()
-        idx_chain = 0
-        for results_dir in results_dir_list:
-            if idx_chain == 1:
-                #try loading fourier chains (only do once)
-                fourier_info = np.loadtxt(results_dir + '/cream_gvalues.dat',skiprows = 1)
-                self.fourier_info = pd.DataFrame(fourier_info,columns = ['angular frequency','prior std',
-                                                                         'gvalue sine','gvalue cos'])
-                ang_freq = list(self.fourier_info['angular frequency'])
-                Nfreq = len(self.fourier_info)
-
-            dat_fourier = pd.DataFrame(np.loadtxt(results_dir + '/CREAM_allpars_BIG.dat')[:, :2*Nfreq])
-            fourier_cols_sine = ['sine '+str(af) for af in ang_freq]
-            fourier_cols_cos = ['cos ' + str(af) for af in ang_freq]
-            fourier_cols = []
-            for i in range(len(fourier_cols_sine)):
-                fourier_cols.append(fourier_cols_sine[i])
-                fourier_cols.append(fourier_cols_cos[i])
-            dat_fourier.columns = fourier_cols
-            dat_fourier['chain number'] = idx_chain
-            idx_chain += 1
-
-        return {'fourier_chains':dat_fourier,
-                'fourier_stats':fourier_info}
-
-
 
 
     def get_light_curve_fits(self,location=None):
@@ -876,14 +749,6 @@ class pycecream:
 
 
 
-def _run_cmd(cmd):
-    '''
-    run the fortran code
-    :param cmd:
-    :return:
-    '''
-    os.system(cmd)
-
 
 
 
